
NSNAM_CODE_BASE_URL = "https://gitlab.com/nsnam/ns-3-dev.git"
PYBINDGEN_BRANCH = 'https://github.com/gjcarneiro/pybindgen.git'
LOCAL_PYBINDGEN_PATH = 'pybindgen'

#
# The last part of the path name to use to find the regression traces tarball.
# path will be APPNAME + '-' + VERSION + REGRESSION_SUFFIX + TRACEBALL_SUFFIX,
# e.g., ns-3-dev-ref-traces.tar.bz2
#
TRACEBALL_SUFFIX = ".tar.bz2"

# NetAnim
NETANIM_REPO = "http://code.nsnam.org/netanim"
NETANIM_RELEASE_URL = "http://www.nsnam.org/tools/netanim"

LOCAL_NETANIM_PATH = "netanim"

# bake
BAKE_REPO = "https://gitlab.com/nsnam/bake.git"
